@@ -1,8 +1,8 @@
 NAME = 'redis_kernel'
-VERSION = '0.2.2'
+VERSION = '0.3'
 LANGUAGE = 'redis'
-BANNER = 'redis kernel 0.2.2'
+BANNER = 'redis kernel 0.3'
 DEFAULT_HOST = 'localhost'
 DEFAULT_PORT = '6379'
 DISPLAY_NAME = 'Redis'
-DESCRIPTION = 'A redis kernel for IPython'
\ No newline at end of file
+DESCRIPTION = 'A redis kernel for IPython'
